==> ah-form-builder-sample-0.6.19.tgz: package/es/components/app/FieldWrapper.js <==
var _jsxFileName = "/var/apps/ah-form-builder/src/components/app/FieldWrapper.js";
import React from 'react';
import { createField as _createField, deleteField as _deleteField } from "../../actions/formActions";
import { enableFieldEdit as _enableFieldEdit, disableFieldEdit as _disableFieldEdit } from '../../actions/toolbarActions';
import { connect } from "react-redux";
import IconButton from '@material-ui/core/IconButton';
import Input from '../../utils/inputs/TextInput';
import InputWrapper from './fields-wrappers/Input';
import DeleteIcon from '@material-ui/icons/Delete';
import CloneIcon from '@material-ui/icons/FileCopy';
import EditIcon from '@material-ui/icons/Edit';
import { Tooltip } from "@material-ui/core";
import SelectWrapper from "./fields-wrappers/Select";
import ButtonGroup from "@material-ui/core/ButtonGroup";
import Button from "@material-ui/core/Button";
import CheckboxWrapper from "./fields-wrappers/Checkbox";
import RadioWrapper from "./fields-wrappers/Radio";
import DateWrapper from "./fields-wrappers/Date";
import ContentWrapper from "./fields-wrappers/Content";
import FileWrapper from "./fields-wrappers/File";
import SectionWrapper from "./fields-wrappers/Section";
import SignatureWrapper from "./fields-wrappers/Signature";
import ImageWrapper from "./fields-wrappers/Image";
import VideoWrapper from "./fields-wrappers/Video";
import { generateUUID } from "../../utils/helpers";
import _ from "lodash";

function FieldWrapper(props) {
  var _this = this;

  var _React$useState = React.useState(false),
      options = _React$useState[0],
      setOptions = _React$useState[1];

  var enableEdit = function enableEdit(e) {
    props.enableFieldEdit(props.data.uuid);
  };

  var removeField = function removeField(e) {
    if (props.editId === props.data.uuid) {
      props.disableFieldEdit();
    }

    props.deleteField(props.data.uuid);
  };

  var cloneField = function cloneField(e) {
    var uuid = generateUUID();
    var machineName = props.data.type + '-' + Math.round(Date.now() / 1000);

    var newData = _.cloneDeep(props.data);

    newData.uuid = uuid;
    newData.machineName = machineName;
    props.createField(newData);
  };

  var showOptions = function showOptions() {
    setOptions(true);
  };

  var hideOptions = function hideOptions() {
    setOptions(false);
  };

  var renderFields = function renderFields(predefined) {
    switch (props.data.type) {
      case 'text':
        return /*#__PURE__*/React.createElement(InputWrapper, {
          data: props.data,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 62,
            columnNumber: 17
          }
        });

      case 'checkbox':
        return /*#__PURE__*/React.createElement(CheckboxWrapper, {
          data: props.data,
          predefined: predefined,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 64,
            columnNumber: 17
          }
        });

      case 'radio':
        return /*#__PURE__*/React.createElement(RadioWrapper, {
          data: props.data,
          predefined: predefined,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 66,
            columnNumber: 17
          }
        });

      case 'select':
        return /*#__PURE__*/React.createElement(SelectWrapper, {
          data: props.data,
          predefined: predefined,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 68,
            columnNumber: 17
          }
        });

      case 'content':
        return /*#__PURE__*/React.createElement(ContentWrapper, {
          data: props.data,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 70,
            columnNumber: 17
          }
        });

      case 'date':
        return /*#__PURE__*/React.createElement(DateWrapper, {
          data: props.data,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 72,
            columnNumber: 17
          }
        });

      case 'file':
        return /*#__PURE__*/React.createElement(FileWrapper, {
          data: props.data,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 74,
            columnNumber: 17
          }
        });

      case 'image':
        return /*#__PURE__*/React.createElement(ImageWrapper, {
          data: props.data,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 76,
            columnNumber: 17
          }
        });

      case 'list':
        return /*#__PURE__*/React.createElement("h1", {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 78,
            columnNumber: 17
          }
        }, "list");

      case 'quiz':
        return /*#__PURE__*/React.createElement("h1", {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 80,
            columnNumber: 17
          }
        }, "quiz");

      case 'signature':
        return /*#__PURE__*/React.createElement(SignatureWrapper, {
          data: props.data,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 82,
            columnNumber: 17
          }
        });

      case 'survey':
        return /*#__PURE__*/React.createElement("h1", {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 84,
            columnNumber: 17
          }
        }, "survey");

      case 'video':
        return /*#__PURE__*/React.createElement(VideoWrapper, {
          data: props.data,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 86,
            columnNumber: 17
          }
        });

      case 'section':
        return /*#__PURE__*/React.createElement(SectionWrapper, {
          data: props.data,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 88,
            columnNumber: 17
          }
        });

      default:
        return /*#__PURE__*/React.createElement("div", {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 91,
            columnNumber: 11
          }
        }, " Default ");
    }
  };

  var className = "wrapper bg-white ml-3 mr-3 p-2";

  if (props.first) {
    className = className + ' first-field';
  }

  if (props.last) {
    className = className + ' last-field';
  }

  var predefined = {};
  props.predefined.map(function (item) {
    predefined[item.id] = item;
  });
  return /*#__PURE__*/React.createElement("div", {
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 107,
      columnNumber: 5
    }
  }, props.data.name || props.data.type === 'content' || props.data.type === 'image' || props.data.type === 'video' ? /*#__PURE__*/React.createElement("div", {
    className: className,
    onMouseEnter: showOptions,
    onMouseLeave: hideOptions,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 109,
      columnNumber: 9
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: "innerWrapper",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 110,
      columnNumber: 11
    }
  }, options ? /*#__PURE__*/React.createElement(ButtonGroup, {
    className: "options-menu",
    color: "primary",
    size: "small",
    "aria-label": "outlined primary button group",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 112,
      columnNumber: 15
    }
  }, /*#__PURE__*/React.createElement(Button, {
    className: "delete-icon",
    onClick: removeField,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 113,
      columnNumber: 17
    }
  }, /*#__PURE__*/React.createElement(DeleteIcon, {
    fontSize: "small",
    color: "action",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 114,
      columnNumber: 19
    }
  })), /*#__PURE__*/React.createElement(Button, {
    className: "edit-icon",
    onClick: enableEdit,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 116,
      columnNumber: 17
    }
  }, /*#__PURE__*/React.createElement(EditIcon, {
    fontSize: "small",
    color: "action",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 117,
      columnNumber: 19
    }
  })), props.data.type !== 'section' ? /*#__PURE__*/React.createElement(Button, {
    className: "clone-icon",
    onClick: cloneField,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 120,
      columnNumber: 19
    }
  }, /*#__PURE__*/React.createElement(Tooltip, {
    title: "Clone field",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 121,
      columnNumber: 19
    }
  }, /*#__PURE__*/React.createElement(CloneIcon, {
    fontSize: "small",
    color: "action",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 122,
      columnNumber: 21
    }
  }))) : '') : "", renderFields(predefined))) : "");
}

var mapStateToProps = function mapStateToProps(state) {
  return {
    editId: state.toolbar.editId,
    predefined: state.form.predefined
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    createField: function createField(id) {
      return dispatch(_createField(id));
    },
    deleteField: function deleteField(id) {
      return dispatch(_deleteField(id));
    },
    enableFieldEdit: function enableFieldEdit(id) {
      return dispatch(_enableFieldEdit(id));
    },
    disableFieldEdit: function disableFieldEdit() {
      return dispatch(_disableFieldEdit());
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(FieldWrapper);

==> ah-form-builder-sample-0.6.85.tgz: package/es/components/app/FieldWrapper.js <==
var _jsxFileName = "/var/www/html/formbuilder/src/components/app/FieldWrapper.js";
import React from 'react';
import { createField as _createField, deleteField as _deleteField } from "../../actions/formActions";
import { enableFieldEdit as _enableFieldEdit, disableFieldEdit as _disableFieldEdit } from '../../actions/toolbarActions';
import { connect } from "react-redux";
import InputWrapper from './fields-wrappers/Input';
import DeleteIcon from '@material-ui/icons/Delete';
import CloneIcon from '@material-ui/icons/FileCopy';
import EditIcon from '@material-ui/icons/Edit';
import { Tooltip } from "@material-ui/core";
import SelectWrapper from "./fields-wrappers/Select";
import ButtonGroup from "@material-ui/core/ButtonGroup";
import Button from "@material-ui/core/Button";
import CheckboxWrapper from "./fields-wrappers/Checkbox";
import RadioWrapper from "./fields-wrappers/Radio";
import DateWrapper from "./fields-wrappers/Date";
import ContentWrapper from "./fields-wrappers/Content";
import FileWrapper from "./fields-wrappers/File";
import SectionWrapper from "./fields-wrappers/Section";
import SignatureWrapper from "./fields-wrappers/Signature";
import ImageWrapper from "./fields-wrappers/Image";
import VideoWrapper from "./fields-wrappers/Video";
import { generateUUID } from "../../utils/helpers";
import { useWindowSize } from "../hooks/useWindowSize";
import _ from "lodash";

function FieldWrapper(props) {
  var _this = this;

  var _React$useState = React.useState(false),
      options = _React$useState[0],
      setOptions = _React$useState[1];

  var _useWindowSize = useWindowSize(),
      width = _useWindowSize.width;

  var enableEdit = function enableEdit(e) {
    props.enableFieldEdit(props.data.uuid);
  };

  var removeField = function removeField(e) {
    if (props.editId === props.data.uuid) {
      props.disableFieldEdit();
    }

    props.deleteField(props.data.uuid);
  };

  var cloneField = function cloneField(e) {
    var uuid = generateUUID();
    var machineName = props.data.type + '-' + Math.round(Date.now() / 1000);

    var newData = _.cloneDeep(props.data);

    newData.uuid = uuid;
    newData.machineName = machineName;
    props.createField(newData);
  };

  var showOptions = function showOptions() {
    setOptions(true);
  };

  var hideOptions = function hideOptions() {
    setOptions(false);
  };

  var renderFields = function renderFields(predefined) {
    switch (props.data.type) {
      case 'text':
        return /*#__PURE__*/React.createElement(InputWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 62,
            columnNumber: 17
          }
        });

      case 'checkbox':
        return /*#__PURE__*/React.createElement(CheckboxWrapper, {
          data: props.data,
          predefined: predefined,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 64,
            columnNumber: 17
          }
        });

      case 'radio':
        return /*#__PURE__*/React.createElement(RadioWrapper, {
          data: props.data,
          predefined: predefined,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 66,
            columnNumber: 17
          }
        });

      case 'select':
        return /*#__PURE__*/React.createElement(SelectWrapper, {
          data: props.data,
          predefined: predefined,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 68,
            columnNumber: 17
          }
        });

      case 'content':
        return /*#__PURE__*/React.createElement(ContentWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 70,
            columnNumber: 17
          }
        });

      case 'date':
        return /*#__PURE__*/React.createElement(DateWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 72,
            columnNumber: 17
          }
        });

      case 'file':
        return /*#__PURE__*/React.createElement(FileWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 74,
            columnNumber: 17
          }
        });

      case 'image':
        return /*#__PURE__*/React.createElement(ImageWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 76,
            columnNumber: 17
          }
        });

      case 'list':
        return /*#__PURE__*/React.createElement("h1", {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 78,
            columnNumber: 17
          }
        }, "list");

      case 'quiz':
        return /*#__PURE__*/React.createElement("h1", {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 80,
            columnNumber: 17
          }
        }, "quiz");

      case 'signature':
        return /*#__PURE__*/React.createElement(SignatureWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 82,
            columnNumber: 17
          }
        });

      case 'survey':
        return /*#__PURE__*/React.createElement("h1", {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 84,
            columnNumber: 17
          }
        }, "survey");

      case 'video':
        return /*#__PURE__*/React.createElement(VideoWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 86,
            columnNumber: 17
          }
        });

      case 'section':
        return /*#__PURE__*/React.createElement(SectionWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 88,
            columnNumber: 17
          }
        });

      default:
        return /*#__PURE__*/React.createElement("div", {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 91,
            columnNumber: 11
          }
        }, " Default ");
    }
  };

  var className = "wrapper ahfb-shadow-1 ahfb-bg-white ahfb-ml-3 ahfb-mr-3 ahfb-p-3 ahfb-relative";

  if (props.first) {
    className = className + ' first-field';
  }

  if (props.last) {
    className = className + ' last-field';
  }

  var predefined = {};
  props.predefined.map(function (item) {
    predefined[item.id] = item;
  });
  return /*#__PURE__*/React.createElement("div", {
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 107,
      columnNumber: 5
    }
  }, props.data.name || props.data.type === 'content' || props.data.type === 'image' || props.data.type === 'video' ? /*#__PURE__*/React.createElement("div", {
    className: className,
    onMouseOver: showOptions,
    onMouseLeave: hideOptions,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 109,
      columnNumber: 9
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: "innerWrapper",
    style: {
      marginTop: width < 450 ? '30px' : ''
    },
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 110,
      columnNumber: 11
    }
  }, options ? /*#__PURE__*/React.createElement(ButtonGroup, {
    className: "options-menu ahfb-absolute ahfb-" + (props.theme.direction ? props.theme.direction : 'ltr') + "-1 ahfb-top-1 ahfb-float-right ahfb-zIndex",
    color: "primary",
    size: "small",
    "aria-label": "outlined primary button group",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 112,
      columnNumber: 15
    }
  }, /*#__PURE__*/React.createElement(Button, {
    className: "delete-icon",
    onClick: removeField,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 113,
      columnNumber: 17
    }
  }, /*#__PURE__*/React.createElement(DeleteIcon, {
    fontSize: "small",
    color: "action",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 114,
      columnNumber: 19
    }
  })), /*#__PURE__*/React.createElement(Button, {
    className: "edit-icon",
    onClick: enableEdit,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 116,
      columnNumber: 17
    }
  }, /*#__PURE__*/React.createElement(EditIcon, {
    fontSize: "small",
    color: "action",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 117,
      columnNumber: 19
    }
  })), props.data.type !== 'section' ? /*#__PURE__*/React.createElement(Button, {
    className: "clone-icon",
    onClick: cloneField,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 120,
      columnNumber: 19
    }
  }, /*#__PURE__*/React.createElement(Tooltip, {
    title: "Clone field",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 121,
      columnNumber: 19
    }
  }, /*#__PURE__*/React.createElement(CloneIcon, {
    fontSize: "small",
    color: "action",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 122,
      columnNumber: 21
    }
  }))) : '') : "", renderFields(predefined))) : "");
}

var mapStateToProps = function mapStateToProps(state) {
  return {
    editId: state.toolbar.editId,
    predefined: state.form.predefined,
    theme: state.form.theme,
    currentLang: state.form.currentLang
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    createField: function createField(id) {
      return dispatch(_createField(id));
    },
    deleteField: function deleteField(id) {
      return dispatch(_deleteField(id));
    },
    enableFieldEdit: function enableFieldEdit(id) {
      return dispatch(_enableFieldEdit(id));
    },
    disableFieldEdit: function disableFieldEdit() {
      return dispatch(_disableFieldEdit());
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(FieldWrapper);
